@@ -426,8 +426,11 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
                 # gives software properties dialogs a chance to interact about
                 # renewals if needed.
                 try:
+                        # Ignore timezone to simplify formatting python < 3.7
+                        # 3.7 has datetime.fromisoformat()
+                        dt, _sep, _tz = status.get("expires", "").partition("+")
                         eol_date = datetime.datetime.strptime(
-                                status.get("expires"), "%Y-%m-%dT%H:%M:%S"
+                            dt, "%Y-%m-%dT%H:%M:%S"
                         ).date()
                 except ValueError:
                         print("Unable to determine UA contract expiry")
